Documentation
¶
Overview ¶
Package baemail interfaces with Deggen's Baemail Read more at: https://baemail.me/
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Network = baemailURL // override the default network UserAgent = defaultUserAgent // override the default user agent )
Override the package defaults
Functions ¶
func Compose ¶
Compose will return a url for composing a baemail Specs: https://baemail.me/compose?to=user%40domain
Types ¶
type Response ¶
type Response struct {
ComposeURL string `json:"compose_url"` // Compose email url
Found bool `json:"found"` // Flag if the profile was found
StatusCode int `json:"status_code"` // Status code returned on the request
Tracing resty.TraceInfo `json:"tracing"` // Trace information if enabled on the request
}
Response is the standard fields returned on all responses
Click to show internal directories.
Click to hide internal directories.